@@ -5,6 +5,9 @@ import casadi
 Variable = casadi.SX.sym
 
 from ._material import (
+    Function,
+    Function as FunctionScalar,
+    FunctionTensor,
     Material,
     Material as MaterialScalar,
     MaterialTensor,
@@ -13,8 +16,12 @@ from . import models
 from . import math
 from ._templates import (
     ThreeFieldVariation,
+    ThreeFieldVariationPlaneStrain,
     MaterialHyperelastic,
     MaterialComposite,
+    MaterialHyperelasticPlaneStrain,
+    MaterialHyperelasticPlaneStressIncompressible,
+    MaterialHyperelasticPlaneStressLinearElastic,
 )
 from ._lab import Lab
 
