@@ -48,8 +48,19 @@ def library():
         md.microsphere.nonaffine.tube: {
             "quadrature": q,
             "q": 2.7,
-            "f": md.microsphere.langevin,
-            "kwargs": {"mu": 1, "N": 10},
+            "f": md.microsphere.linear,
+            "kwargs": {"mu": 1},
+        },
+        matadi.models.miehe_goektepe_lulei: {
+            "mu": 0.1475,
+            "N": 3.273,
+            "p": 9.31,
+            "U": 9.94,
+            "q": 0.567,
+        },
+        matadi.models.linear_elastic: {
+            "mu": 1.0,
+            "lmbda": 2.0,
         },
     }
 
@@ -71,14 +82,14 @@ def test_models():
 
     for model, kwargs in lib.items():
 
-        if model is not md.saint_venant_kirchhoff:
+        if model not in [md.saint_venant_kirchhoff, md.linear_elastic]:
             kwargs["bulk"] = 5000.0
 
         HM = matadi.MaterialHyperelastic(model, **kwargs)
         HM_mixed = matadi.ThreeFieldVariation(HM)
 
         W = HM.function([FF])
-        P = HM.gradient([FF])
+        P = HM.gradient([FF], threads=1)
         A = HM.hessian([FF])
 
         assert len(W) == 1
@@ -93,6 +104,33 @@ def test_models():
         assert len(P) == 3
         assert len(A) == 6
 
+    nh = matadi.MaterialHyperelastic(md.neo_hooke, **lib[md.neo_hooke])
+    mr = matadi.MaterialHyperelastic(md.mooney_rivlin, **lib[md.mooney_rivlin])
+
+    comp = matadi.MaterialComposite([nh, mr])
+    comp.fun()
+
+    W = comp.function([FF])
+    P = comp.gradient([FF])
+    A = comp.hessian([FF])
+
+    assert len(W) == 1
+    assert len(P) == 1
+    assert len(A) == 1
+
+    nh_mixed = matadi.ThreeFieldVariation(nh)
+    mr_mixed = matadi.ThreeFieldVariation(mr)
+
+    comp = matadi.MaterialComposite([nh_mixed, mr_mixed])
+
+    W = comp.function([FF, pp, JJ])
+    P = comp.gradient([FF, pp, JJ])
+    A = comp.hessian([FF, pp, JJ])
+
+    assert len(W) == 1
+    assert len(P) == 3
+    assert len(A) == 6
+
 
 if __name__ == "__main__":
     test_models()
